# -*- coding: utf-8 -*-
# Copyright (c) 2011 Infrae. All rights reserved.
# See also LICENSE.txt
# $Id$

from collective.cmisbrowser.errors import CMISConnectorError
from collective.cmisbrowser.cmis.api import CMISZopeAPI
from Products.Five import BrowserView


class CMISQueryView(BrowserView):
    """CMIS Query view
    """

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.results = []
        self.feedback = u''

    def update(self):
        browser = self.context.getBrowser()
        if browser is not None:
            try:
                api = CMISZopeAPI(browser)
                self.results = api.query(self.context.query)
            except CMISConnectorError:
                self.feedback = u'Connector error.'
        else:
            self.feedback = u'Browser not configured.'
        return self.results



# -*- coding: utf-8 -*-
# Copyright (c) 2011 Infrae. All rights reserved.
# See also LICENSE.txt
# $Id$


from zope.schema import Text
from infrae.plone.relations.schema import PloneRelation
from zope.interface import Interface


class ICMISQuery(Interface):
    text = Text(
        title=u"Text",
        description=u"Text display before the results",
        required=False)
    browser = PloneRelation(
        title=u"Browser",
        description=u"CMIS Browser object to use in order to query for results",
        unique=True,
        max_length=1,
        relation="cmisbrowser")
    query = Text(
        title=u"Query",
        description=u"CMIS Query",
        default=u"SELECT R.* FROM cmis:document R WHERE CONTAINS('test')",
        required=True)

    def getBrowser():
        """Return the currently configured browser, or None
        """



# -*- coding: utf-8 -*-
# Copyright (c) 2011 Infrae. All rights reserved.
# See also LICENSE.txt
# $Id$


from zope.interface import implements
from zope.schema.fieldproperty import FieldProperty
from zope.component.factory import Factory

from plone.app.content.item import Item
from collective.cmisquery.interfaces import ICMISQuery
from plone.app.content.interfaces import INameFromTitle


class CMISQuery(Item):
    portal_type = "CMIS Query"
    implements(INameFromTitle, ICMISQuery)

    text = FieldProperty(ICMISQuery['text'])
    browser = FieldProperty(ICMISQuery['browser'])
    query = FieldProperty(ICMISQuery['query'])

    def getBrowser(self):
        # This cannot be done inside a property since acquisition is
        # disabled inside it, so the intid of self doesn't resolve.
        field = ICMISQuery['browser']
        try:
            data = field.get(self)
        except TypeError:
            raise ValueError(u"plone.app.relation is not installed")
        if data:
            return list(data[0]['objects'])[0]
        return None


CMISQueryFactory = Factory(CMISQuery, title=u"Create CMIS Query")



# Copyright (c) 2013 Beleidsdomein Leefmilieu, Natuur and Energie (LNE) en Vlaamse Milieumaatschappij (VMM). All rights reserved.
# See also LICENSE.txt

# See http://peak.telecommunity.com/DevCenter/setuptools#namespace-packages
try:
    __import__('pkg_resources').declare_namespace(__name__)
except ImportError:
    from pkgutil import extend_path
    __path__ = extend_path(__path__, __name__)



# Copyright (c) 2013 Beleidsdomein Leefmilieu, Natuur and Energie (LNE) en Vlaamse Milieumaatschappij (VMM). All rights reserved.
# See also LICENSE.txt

import os, sys
from setuptools import setup, find_packages

version = '1.0'

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

long_description = (
    read('README.rst')
    + '\n' +
    read('docs/HISTORY.txt')
    )
requires = [
    "setuptools",
    "zope.schema",
    "plone.app.content",
    "plone.app.form",
    "infrae.plone.relations.form",
    "infrae.plone.relations.schema",
    "collective.cmisbrowser",
    ]

tests_requires = [
    "Products.PloneTestCase"
    ]

setup(name='collective.cmisquery',
      version=version,
      description="CMIS repository query for Plone",
      long_description=long_description,
      classifiers=[
        "Framework :: Plone",
        "Framework :: Zope2",
        ],
      keywords='CMIS connection query browser plone',
      author='Sylvain Viollon',
      author_email='sylvain@infrae.com',
      url='http://pypi.python.org/pypi/collective.cmisquery',
      license='GPL',
      package_dir={'': 'src'},
      packages=find_packages('src'),
      namespace_packages=['collective'],
      include_package_data=True,
      zip_safe=False,
      install_requires=requires,
      tests_require = tests_requires,
      extras_require = {'test': tests_requires},
      )



# -*- coding: utf-8 -*-
# Copyright (c) 2011 Infrae. All rights reserved.
# See also LICENSE.txt
# $Id$

from plone.app.form.widgets.wysiwygwidget import WYSIWYGWidget
from plone.app.form.base import AddForm, EditForm
from plone.app.content.interfaces import INameFromTitle
from zope.formlib.form import applyChanges, Fields
from zope.component import createObject
from collective.cmisquery.content.cmisquery import ICMISQuery

from infrae.plone.relations.form import PloneRelationEditWidget
from infrae.plone.relations.form import PloneRelationSearchAddWidget
from zope.app.form import CustomWidgetFactory

widget_factory = CustomWidgetFactory(
    PloneRelationEditWidget,
    add_widget=PloneRelationSearchAddWidget,
    add_widget_args=dict(content_type='CMIS Browser'))


class CMISQueryAddForm(AddForm):
    label = u'Add a CMIS Query'
    form_fields = Fields(INameFromTitle, ICMISQuery)
    form_fields['browser'].custom_widget = widget_factory
    form_fields['text'].custom_widget = WYSIWYGWidget

    def create(self, data):
        query = createObject(u"collective.cmisquery.CMISQuery")
        content = self.context.add(query)
        # We need to add the content before editing it, in order to
        # have a working reference: we would get not yet overwise.
        applyChanges(content, self.form_fields, data)
        return content

    def add(self, content):
        self._finished_add = True
        return content



class CMISQueryEditForm(EditForm):
    label = u'Edit a CMIS Query'
    form_fields = Fields(ICMISQuery)
    form_fields['browser'].custom_widget = widget_factory
    form_fields['text'].custom_widget = WYSIWYGWidget
